@@ -92,23 +92,6 @@ struct sf_vec {
       } else {
         SET_STRING_ELT(data2, i, Rf_mkCharLenCE(data1[i].sdata.c_str(), data1[i].sdata.size(), static_cast<cetype_t>(data1[i].encoding)));
       }
-      // switch(data1.encodings[i]) {
-      // case 0:
-      //   SET_STRING_ELT(data2, i, Rf_mkCharLenCE(data1.strings[i].data(), data1.strings[i].size(), CE_NATIVE) );
-      //   break;
-      // case 1:
-      //   SET_STRING_ELT(data2, i, Rf_mkCharLenCE(data1.strings[i].data(), data1.strings[i].size(), CE_UTF8) );
-      //   break;
-      // case 2:
-      //   SET_STRING_ELT(data2, i, Rf_mkCharLenCE(data1.strings[i].data(), data1.strings[i].size(), CE_LATIN1) );
-      //   break;
-      // case 3:
-      //   SET_STRING_ELT(data2, i, Rf_mkCharLenCE(data1.strings[i].data(), data1.strings[i].size(), CE_BYTES) );
-      //   break;
-      // default:
-      //   SET_STRING_ELT(data2, i, NA_STRING);
-      // break;
-      // }
     }
     
     R_set_altrep_data2(vec, data2);
@@ -129,7 +112,6 @@ struct sf_vec {
     return STDVEC_DATAPTR(Materialize(vec));
   }
   
-  
   // ALTSTRING methods -----------------
   // the element at the index `i`
   // this does not do bounds checking because that's expensive, so
@@ -189,7 +171,7 @@ struct sf_vec {
   
   static SEXP Extract_subset(SEXP x, SEXP indx, SEXP call) {
     SEXP data2 = R_altrep_data2(x);
-    if(data2 == nullptr) {
+    if(data2 != nullptr) {
       return nullptr;
     }
     
